==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/JobConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class JobConditionBuilder extends JobConditionFluentImpl<JobConditionBuilder> implements VisitableBuilder<JobCondition,JobConditionBuilder>{

    JobConditionFluent<?> fluent;
    Boolean validationEnabled;

    public JobConditionBuilder(){
            this(true);
    }
    public JobConditionBuilder(Boolean validationEnabled){
            this(new JobCondition(), validationEnabled);
    }
    public JobConditionBuilder(JobConditionFluent<?> fluent){
            this(fluent, true);
    }
    public JobConditionBuilder(JobConditionFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new JobCondition(), validationEnabled);
    }
    public JobConditionBuilder(JobConditionFluent<?> fluent,JobCondition instance){
            this(fluent, instance, true);
    }
    public JobConditionBuilder(JobConditionFluent<?> fluent,JobCondition instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withLastProbeTime(instance.getLastProbeTime()); 
            fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
            fluent.withMessage(instance.getMessage()); 
            fluent.withReason(instance.getReason()); 
            fluent.withStatus(instance.getStatus()); 
            fluent.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }
    public JobConditionBuilder(JobCondition instance){
            this(instance,true);
    }
    public JobConditionBuilder(JobCondition instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withLastProbeTime(instance.getLastProbeTime()); 
            this.withLastTransitionTime(instance.getLastTransitionTime()); 
            this.withMessage(instance.getMessage()); 
            this.withReason(instance.getReason()); 
            this.withStatus(instance.getStatus()); 
            this.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }

    public JobCondition build(){
            JobCondition buildable = new JobCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            JobConditionBuilder that = (JobConditionBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/JobConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class JobConditionBuilder extends JobConditionFluentImpl<JobConditionBuilder> implements VisitableBuilder<JobCondition,JobConditionBuilder>{

    JobConditionFluent<?> fluent;
    Boolean validationEnabled;

    public JobConditionBuilder(){
            this(true);
    }
    public JobConditionBuilder(Boolean validationEnabled){
            this(new JobCondition(), validationEnabled);
    }
    public JobConditionBuilder(JobConditionFluent<?> fluent){
            this(fluent, true);
    }
    public JobConditionBuilder(JobConditionFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new JobCondition(), validationEnabled);
    }
    public JobConditionBuilder(JobConditionFluent<?> fluent,JobCondition instance){
            this(fluent, instance, true);
    }
    public JobConditionBuilder(JobConditionFluent<?> fluent,JobCondition instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withLastProbeTime(instance.getLastProbeTime()); 
            fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
            fluent.withMessage(instance.getMessage()); 
            fluent.withReason(instance.getReason()); 
            fluent.withStatus(instance.getStatus()); 
            fluent.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }
    public JobConditionBuilder(JobCondition instance){
            this(instance,true);
    }
    public JobConditionBuilder(JobCondition instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withLastProbeTime(instance.getLastProbeTime()); 
            this.withLastTransitionTime(instance.getLastTransitionTime()); 
            this.withMessage(instance.getMessage()); 
            this.withReason(instance.getReason()); 
            this.withStatus(instance.getStatus()); 
            this.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }

    public JobCondition build(){
            JobCondition buildable = new JobCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            JobConditionBuilder that = (JobConditionBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
